@@ -1,8 +1,6 @@
-"""
-Constantin Werner. 24.12.2020
-const.werner@gmail.com
-
-"""
+#!/usr/bin/env python
+# -*- coding: utf-8 -*- 
+# encoding=utf8  
 import time
 import re
 import requests
